# How to Contribute to hesseflux

``hesseflux`` development is driven by user feedback, and your contributions help
to find bugs, add features, and improve performance. This is a small guide to
help those who wish to contribute.

We are happy about all contributions! :thumbsup:


## Did you find a bug?

- Ensure that the bug was not already reported under [GitHub issues](https://github.com/mcuntz/hesseflux/issues)
- If the bug was not already reported, open a [new issue](https://github.com/mcuntz/hesseflux/issues)
with a clear description of the problem and if possible with a
[minimal working example](https://en.wikipedia.org/wiki/Minimal_working_example).
- please add the version number to the issue:

```python
import hesseflux
print(hesseflux.__version__)
```

## Do you have suggestions for new features?

Open a [new issue](https://github.com/mcuntz/hesseflux/issues)
with your idea or suggestion and we'd love to discuss about it.


## Do you want to enhance hesseflux or fix something?

- Fork the repo on [GitHub](https://github.com/mcuntz/hesseflux).
- Add yourself to AUTHORS.md, if you want to.
- Add some tests, if possible.
- Push to your fork and submit a pull request.
